@@ -52,6 +52,20 @@ const bool DEF_ENABLE_EXT_VIEWER = true;
 const bool DEF_INCLUDE_CURSOR = false;
 const bool DEF_FIT_INSIDE = true;
 
+class Settings : public QSettings // prevents redundant writings
+{
+    Q_OBJECT
+public:
+    Settings(const QString &organization, const QString &application = QString(), QObject *parent = nullptr)
+        : QSettings (organization, application, parent) {}
+
+    void setValue(const QString &key, const QVariant &v) {
+        if (value(key) == v)
+            return;
+        QSettings::setValue(key, v);
+    }
+};
+
 // class worker with conf data
 class Config
 {
@@ -99,12 +113,6 @@ public:
     static void killInstance();
     ~Config();
 
-    /**
-     * @brief Gets the configuration file for screengrab. It's
-     * inside the folder returned by getConfigDir().
-     */
-    static QString getConfigFile();
-
     /**
      * @brief Gets the directory where to save the configuration files.
      * Does not end with '/'.
@@ -121,6 +129,11 @@ public:
      */
     void saveSettings();
 
+    /**
+     * Save screenshot settings to conf file
+     */
+    void saveScreenshotSettings();
+
     /**
      * Reset configuration data from default values
      */
@@ -138,10 +151,6 @@ public:
     QString getSaveFormat();
     void setSaveFormat(QString format);
 
-    // default delay
-    quint8 getDefDelay();
-    void setDefDelay(quint8 sec);
-
     quint8 getDelay();
     void setDelay(quint8 sec);
 
@@ -149,10 +158,6 @@ public:
     int getDefScreenshotType();
     void setDefScreenshotType(const int type);
 
-    // current screenshot type
-    int getScreenshotType();
-    void setScreenshotType(const int type);
-
     quint8 getAutoCopyFilenameOnSaving();
     void setAutoCopyFilenameOnSaving(quint8 val);
 
@@ -192,7 +197,8 @@ public:
     void setRestoredWndSize(int w, int h);
     void saveWndSize();
 
-    // get default image save format
+    // get image save format(s)
+    QStringList getFormatIDs() const;
     int getDefaultFormatID();
     QString getDirNameDefault();
 
@@ -229,6 +235,9 @@ public:
     bool getFitInside();
     void setFitInside(bool val);
 
+    QRect getLastSelection();
+    void setLastSelection(QRect rect);
+
     static QString getSysLang();
 
     ShortcutManager* shortcuts();
@@ -256,13 +265,11 @@ private:
      */
     void setValue(const QString& key, QVariant val);
 
-    QSettings *_settings;
+    Settings *_settings;
     QHash<QString, QVariant> _confData;
 
     ShortcutManager *_shortcuts;
 
-    QVector<QString> _imageFormats;
-
     int _scrNum; // screen num in session
     QDateTime _dateLastSaving;
 };
